==> mywwwatcher-3.1.tbz: www/mywwwatcher/charset.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

include ("include/headers.inc.php");

$charset_columns = array("varchar", "enum", "text", "char");

function arrayinstr($haystack, $needle) {
   foreach($needle as $value) {
      if (!strpos($haystack, $value) === false or $haystack == $value)
         return (true);
   }
   return (false);
}

?>

<body leftmargin="13" topmargin="13" bottommargin="30" rightmargin="5" bgcolor="<?php echo $_SESSION['color_right'];?>">

<?php

echo "<b>" . CHARSET . "</b><br/><br/>\n";


$ver = mysql_query ("show variables like 'version'");

if ( ereg ("^3\..*$", mysql_result ($ver,0,1)) or ereg ("^4\.0.*$", mysql_result ($ver,0,1)) ) echo VER_BAD;
else    {
    echo CHARSET_TEXT_1 . "<br/><br/>";
    echo CHARSET_TEXT_2 . "<br/><br/>";
    echo "<strong>" . CHARSET_TEXT_3 . "</strong>";

    $result = mysql_query ("SHOW VARIABLES LIKE 'character_set_server'");
    echo "<br/>" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";
    $result = mysql_query ("SHOW VARIABLES LIKE 'collation_server'");
    echo "<br/>" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";

    echo "<br/><br/><strong>" . CHARSET_TEXT_4 . "</strong>\n\n";

    $result = mysql_query ("SHOW VARIABLES LIKE 'character_set_database'");
    echo "<br/>" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";
    $charset_db = mysql_result ($result,0,1);

    $result = mysql_query ("SHOW VARIABLES LIKE 'collation_database'");
    echo "<br/>" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";
    $collation_db = mysql_result ($result,0,1);


    echo "<br/><br/>";
    echo "<strong>" . CHARSET_TEXT_5 ."</strong><br/>";


    $result = mysql_list_tables($_SESSION[xdb]);

    while ($row = mysql_fetch_row($result)) {

        $sql = "SHOW FULL COLUMNS FROM  $row[0]";
        $rs = mysql_query($sql);
        echo "<strong>" . TABLE . " $row[0]</strong><br/>";
        while ($row2 = mysql_fetch_assoc ($rs)) {
            if (arrayinstr(strtolower ($row2['Type']), $charset_columns))    {
                $charset = substr ($row2[Collation],0, strpos ($row2[Collation],"_"));
                if ($charset != $charset_db)
                    echo "<font color=\"red\">" . $row2[Field] . " "  . $row2[Type] . " " . $row2[Collation] . "</font></br>";
                else
                    echo $row2[Field] . " "  . $row2[Type] . " " . $row2[Collation] . "<br/>";
            }
        }
    }



    echo "<br/><br/>" . CHARSET_TEXT_6 . "<br/>";

/*
    echo "<form method=\"post\">\n\n";
    echo "Zmenit vychozi kodovani databaze na $charset_db <input type=\"submit\" name=\"conv_db\" value=\"Proved\"><br/><br/>\n";
    echo "Zmenit vychozi kodovani tabulky na $charset_db ";
    echo "<select name=\"tbname\" size=5>";

	$result = mysql_list_tables ($_SESSION['xdb'], $db);
	for ($i = 0; $i < mysql_num_rows ($result); $i++)	 {
		echo "<option value=\"" . mysql_tablename ($result,$i) . "\">" . mysql_tablename ($result,$i) . "</option>\n";
    }

    echo "</select>\n";
    echo "<input type=\"submit\" name=\"conv_table\" value=\"Proved\"><br/><br/>\n";

    echo "Zmenit vychozi kodovani jednotlivych sloupcu na $charset_db";
	$result = mysql_list_tables ($_SESSION['xdb'], $db);

	for ($i = 0; $i < mysql_num_rows ($result); $i++)	 {

        $fields = mysql_list_fields($_SESSION['xdb'], mysql_tablename ($result,$i));
        $columns = mysql_num_fields($fields);


        $sql = "SHOW FULL COLUMNS FROM " . mysql_tablename ($result,$i);
        $rs = mysql_query($sql);
        while ($row = mysql_fetch_assoc ($rs)) {
            if (arrayinstr(strtolower ($row['Type']), $charset_columns))    {
                echo "<br/>" . mysql_tablename ($result,$i) . " - " . $row[Field] . " "  . $row[Type] . " " . $row[Collation];
            }
        }
    }
    echo "<input type=\"submit\" name=\"conv_column\" value=\"Proved\"><br/><br/>\n";
    echo "</form>\n\n<br/><br/>";
*/


    echo CHARSET_TEXT_7 . "<br/><br/>";

    echo "<strong>ALTER DATABASE db_name [[DEFAULT] CHARACTER SET charset_name] [[DEFAULT] COLLATE collation_name]</strong>";
    echo "<br/>" . CHARSET_TEXT_8 . "<br/><br/>";

    echo "<strong>ALTER TABLE tbl_name [[DEFAULT] CHARACTER SET charset_name] [COLLATE collation_name]</strong>";
    echo "<br/>" . CHARSET_TEXT_9 . "<br/><br/>";


    echo "<strong>ALTER TABLE tbl_name [[DEFAULT] modify sloupec CHARACTER SET charset_name] [COLLATE collation_name]</strong>";
    echo "<br/>" . CHARSET_TEXT_10 . "<br/><br/>";

    echo "<strong>SHOW create database dbname </strong>";
    echo "<br/>" . CHARSET_TEXT_11 ."<br/><br/>";

    echo "<strong>SHOW create table tablename </strong>";
    echo "<br/>" . CHARSET_TEXT_12 . "<br/><br/>";

    echo "<strong>show TABLE STATUS LIKE 'citaty_autori'</strong>";
    echo "<br/>" . CHARSET_TEXT_13 . "<br/><br/>";

    echo "<br/><br/><strong>" . CHARSET_TEXT_14 . " </strong> ";
    echo "<a href=\"queries.php?current_query=" . urlencode("show charset") . "\" target=\"frm_right\">show charset</a>\n";
    echo "<br/><br/><strong>" . CHARSET_TEXT_15 . " </strong> ";
    echo "<a href=\"queries.php?current_query=" . urlencode("show collation") . "\" target=\"frm_right\">show collation</a>\n";





}

include ("include/foot.inc.php");
?>

==> mywwwatcher-3.2.tbz: www/mywwwatcher/charset.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

include ("include/headers.inc.php");

$charset_columns = array("varchar", "enum", "text", "char");

function arrayinstr($haystack, $needle) {
   foreach($needle as $value) {
      if (!strpos($haystack, $value) === false or $haystack == $value)
         return (true);
   }
   return (false);
}

?>

<body id="frm_right" bgcolor="<?php echo $_SESSION['color_right'];?>">

<?php

echo "<strong>" . CHARSET . "</strong><br /><br />\n";


$ver = mysql_query ("show variables like 'version'");

if ( ereg ("^3\..*$", mysql_result ($ver,0,1)) or ereg ("^4\.0.*$", mysql_result ($ver,0,1)) ) echo VER_BAD;
else    {
    echo CHARSET_TEXT_1 . "<br /><br />";
    echo CHARSET_TEXT_2 . "<br /><br />";
    echo "<strong>" . CHARSET_TEXT_3 . "</strong>";

    $result = mysql_query ("SHOW VARIABLES LIKE 'character_set_server'");
    echo "<br />" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";
    $result = mysql_query ("SHOW VARIABLES LIKE 'collation_server'");
    echo "<br />" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";

    echo "<br /><br /><strong>" . CHARSET_TEXT_4 . "</strong>\n\n";

    $result = mysql_query ("SHOW VARIABLES LIKE 'character_set_database'");
    echo "<br />" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";
    $charset_db = mysql_result ($result,0,1);

    $result = mysql_query ("SHOW VARIABLES LIKE 'collation_database'");
    echo "<br />" . mysql_result ($result,0,0) . " : " . mysql_result ($result,0,1) . "\n";
    $collation_db = mysql_result ($result,0,1);


    echo "<br /><br />";
    echo "<strong>" . CHARSET_TEXT_5 ."</strong><br />";


    $result = mysql_list_tables($_SESSION[xdb]);

    while ($row = mysql_fetch_row($result)) {

        $sql = "SHOW FULL COLUMNS FROM  $row[0]";
        $rs = mysql_query($sql);
        echo "<br /><strong>" . TABLE . " $row[0]</strong><br />\n";
        while ($row2 = mysql_fetch_assoc ($rs)) {
            if (arrayinstr(strtolower ($row2['Type']), $charset_columns))    {
                $charset = substr ($row2[Collation],0, strpos ($row2[Collation],"_"));
                if ($charset != $charset_db)
                    echo "<font color=\"red\">" . $row2[Field] . " "  . $row2[Type] . " " . $row2[Collation] . "</font><br />\n";
                else
                    echo $row2[Field] . " "  . $row2[Type] . " " . $row2[Collation] . "<br />\n";
            }
        }
    }



    echo "<br /><br />" . CHARSET_TEXT_6 . "<br />\n";

/*
    echo "<form method=\"post\">\n\n";
    echo "Zmenit vychozi kodovani databaze na $charset_db <input type=\"submit\" name=\"conv_db\" value=\"Proved\"><br /><br />\n";
    echo "Zmenit vychozi kodovani tabulky na $charset_db ";
    echo "<select name=\"tbname\" size=5>";

	$result = mysql_list_tables ($_SESSION['xdb'], $db);
	for ($i = 0; $i < mysql_num_rows ($result); $i++)	 {
		echo "<option value=\"" . mysql_tablename ($result,$i) . "\">" . mysql_tablename ($result,$i) . "</option>\n";
    }

    echo "</select>\n";
    echo "<input type=\"submit\" name=\"conv_table\" value=\"Proved\"><br /><br />\n";

    echo "Zmenit vychozi kodovani jednotlivych sloupcu na $charset_db";
	$result = mysql_list_tables ($_SESSION['xdb'], $db);

	for ($i = 0; $i < mysql_num_rows ($result); $i++)	 {

        $fields = mysql_list_fields($_SESSION['xdb'], mysql_tablename ($result,$i));
        $columns = mysql_num_fields($fields);


        $sql = "SHOW FULL COLUMNS FROM " . mysql_tablename ($result,$i);
        $rs = mysql_query($sql);
        while ($row = mysql_fetch_assoc ($rs)) {
            if (arrayinstr(strtolower ($row['Type']), $charset_columns))    {
                echo "<br />" . mysql_tablename ($result,$i) . " - " . $row[Field] . " "  . $row[Type] . " " . $row[Collation];
            }
        }
    }
    echo "<input type=\"submit\" name=\"conv_column\" value=\"Proved\"><br /><br />\n";
    echo "</form>\n\n<br /><br />";
*/


    echo "<p>". CHARSET_TEXT_7 . "</p>";

    echo "<strong>ALTER DATABASE db_name [[DEFAULT] CHARACTER SET charset_name] [[DEFAULT] COLLATE collation_name]</strong>";
    echo "<br />" . CHARSET_TEXT_8 . "<br /><br />";

    echo "<strong>ALTER TABLE tbl_name [[DEFAULT] CHARACTER SET charset_name] [COLLATE collation_name]</strong>";
    echo "<br />" . CHARSET_TEXT_9 . "<br /><br />";


    echo "<strong>ALTER TABLE tbl_name [[DEFAULT] modify sloupec CHARACTER SET charset_name] [COLLATE collation_name]</strong>";
    echo "<br />" . CHARSET_TEXT_10 . "<br /><br />";

    echo "<strong>SHOW create database dbname </strong>";
    echo "<br />" . CHARSET_TEXT_11 ."<br /><br />";

    echo "<strong>SHOW create table tablename </strong>";
    echo "<br />" . CHARSET_TEXT_12 . "<br /><br />";

    echo "<strong>show TABLE STATUS LIKE 'citaty_autori'</strong>";
    echo "<br />" . CHARSET_TEXT_13 . "<br /><br />";

    echo "<br /><br /><strong>" . CHARSET_TEXT_14 . " </strong> ";
    echo "<a href=\"queries.php?current_query=" . urlencode("show charset") . "\" target=\"frm_right\">show charset</a>\n";
    echo "<br /><br /><strong>" . CHARSET_TEXT_15 . " </strong> ";
    echo "<a href=\"queries.php?current_query=" . urlencode("show collation") . "\" target=\"frm_right\">show collation</a>\n";





}

include ("include/foot.inc.php");
?>
